@@ -483,6 +483,9 @@ iptables -t nat -X
 iptables --policy INPUT ACCEPT
 iptables --policy FORWARD ACCEPT
 iptables --policy OUTPUT ACCEPT 
+ip6tables --policy INPUT ACCEPT
+ip6tables --policy FORWARD ACCEPT
+ip6tables --policy OUTPUT ACCEPT
 sysctl_file_enable_ipv6
 """
         return self.systemdfilepaths.nuke_bash, text
@@ -498,6 +501,9 @@ echo "off-D"
 iptables -D INPUT -j RB_RELATED_AND_ESTABLISHED
 iptables -D OUTPUT -j RB_OUTPUT_VPN_KILL_SWITCH
 iptables -D DOCKER-USER -j RB_DOCKER_VPN_KILL_SWITCH
+ip6tables --policy INPUT ACCEPT
+ip6tables --policy FORWARD ACCEPT
+ip6tables --policy OUTPUT ACCEPT
 sysctl_file_enable_ipv6
 """
         return self.systemdfilepaths.off_bash, text
@@ -521,6 +527,9 @@ echo "flush-D"
 iptables --delete-chain RB_RELATED_AND_ESTABLISHED
 iptables --delete-chain RB_OUTPUT_VPN_KILL_SWITCH
 iptables --delete-chain RB_DOCKER_VPN_KILL_SWITCH
+ip6tables --policy INPUT ACCEPT
+ip6tables --policy FORWARD ACCEPT
+ip6tables --policy OUTPUT ACCEPT
 sysctl_file_enable_ipv6
 """
         return self.systemdfilepaths.flush_bash, text
@@ -536,6 +545,9 @@ iptables --policy OUTPUT ACCEPT
 create_filter_chain 'RB_RELATED_AND_ESTABLISHED'
 create_filter_rule 'iptables -A RB_RELATED_AND_ESTABLISHED -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -I INPUT -j RB_RELATED_AND_ESTABLISHED'
+ip6tables --policy INPUT DROP
+ip6tables --policy FORWARD DROP
+ip6tables --policy OUTPUT DROP
 sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.protect_bash, text
@@ -566,6 +578,9 @@ create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.0.0.0/8 -j ACCEP
 #create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.17.0.1 -j ACCEPT'
 #let's pop a reroute to our vpn rules at the top of the OUTPUT chain using -I insert
 create_filter_rule 'iptables -I OUTPUT  -j RB_OUTPUT_VPN_KILL_SWITCH'
+ip6tables --policy INPUT DROP
+ip6tables --policy FORWARD DROP
+ip6tables --policy OUTPUT DROP
 sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.vpn4_bash, text
@@ -611,6 +626,9 @@ create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.0.0.0/8 -j ACCEP
 #create_filter_rule 'iptables -A RB_OUTPUT_VPN_KILL_SWITCH -d 10.17.0.1 -j ACCEPT'
 #let's pop a reroute to our vpn rules at the top of the OUTPUT chain using -I insert
 create_filter_rule 'iptables -I OUTPUT -j RB_OUTPUT_VPN_KILL_SWITCH'
+ip6tables --policy INPUT DROP
+ip6tables --policy FORWARD DROP
+ip6tables --policy OUTPUT DROP
 sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.vpn4_bash, text
@@ -624,6 +642,9 @@ create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -o tun+ -j ACCEPT'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -i tun+ -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -j DROP'
 create_filter_rule 'iptables -I DOCKER-USER  -j RB_DOCKER_VPN_KILL_SWITCH'
+ip6tables --policy INPUT DROP
+ip6tables --policy FORWARD DROP
+ip6tables --policy OUTPUT DROP
 sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.docker_bash, text
@@ -648,6 +669,9 @@ create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH -o tun+ -p icmp -j ACC
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH  -i tun+ -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT'
 create_filter_rule 'iptables -A RB_DOCKER_VPN_KILL_SWITCH  -j DROP'
 create_filter_rule 'iptables -I DOCKER-USER  -j RB_DOCKER_VPN_KILL_SWITCH'
+ip6tables --policy INPUT DROP
+ip6tables --policy FORWARD DROP
+ip6tables --policy OUTPUT DROP
 sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.docker_bash, text
